Specification

Struct Specification 

pub struct Specification<T = Metadata> {
Show 26 fields pub authors: Vec<String>, pub bindir: Option<String>, pub cert_chain: Option<Vec<String>>, pub dependencies: Option<Vec<Dependency>>, pub description: Option<String>, pub email: Vec<String>, pub executables: Option<Vec<String>>, pub extensions: Option<Vec<String>>, pub extensions_dir: Option<String>, pub extra_rdoc_files: Option<Vec<String>>, pub files: Vec<String>, pub homepage: Option<String>, pub licenses: Vec<String>, pub metadata: Option<T>, pub name: String, pub platform: Option<Platform>, pub post_install_message: Option<String>, pub rdoc_options: Option<Vec<String>>, pub require_paths: Option<Vec<String>>, pub required_ruby_version: Option<Requirement>, pub required_rubygems_version: Option<Requirement>, pub requirements: Option<Vec<String>>, pub rubygems_version: Option<String>, pub signing_key: Option<String>, pub summary: String, pub version: Version,
}
The package information for a gem, typically defined in a .gemspec file.

This is the tag !ruby/object:Gem::Specification in YAML.

Note that we (pedantically) distinguish between Option<Vec<T> and Vec<T> so as to indicate whether the property was unset or set to empty the input specification file.

See: https://guides.rubygems.org/specification-reference/

Fields

authors: Vec<String>bindir: Option<String>cert_chain: Option<Vec<String>>dependencies: Option<Vec<Dependency>>description: Option<String>email: Vec<String>executables: Option<Vec<String>>extensions: Option<Vec<String>>extensions_dir: Option<String>extra_rdoc_files: Option<Vec<String>>files: Vec<String>homepage: Option<String>licenses: Vec<String>metadata: Option<T>name: Stringplatform: Option<Platform>post_install_message: Option<String>rdoc_options: Option<Vec<String>>require_paths: Option<Vec<String>>required_ruby_version: Option<Requirement>required_rubygems_version: Option<Requirement>requirements: Option<Vec<String>>rubygems_version: Option<String>signing_key: Option<String>summary: Stringversion: Version